# Xiaomi Mi Scale

Libraries to read weight measurements from [Mi Body Composition Scale](https://www.mi.com/global/mi-body-composition-scale/) (aka Xiaomi Mi Scale V2)
Also works with [Mi Body Composition Scale 2](https://c.mi.com/thread-2289389-1-0.html) (Model # XMTZC05HM)


Note: Framework is present to also read from Xiaomi Scale V1, although I do not own one to test so the code has not been maintained

See my [github](https://github.com/lolouk44/xiaomi_mi_scale) page for more information